load_layers

Function load_layers 

pub fn load_layers<P: AsRef<Path>>(
    paths: &[P],
    explicit_format: Option<Format>,
) -> Result<Layers>
Read homogeneous native layers after resolving one format for the entire list.

Stdin requires an explicit format. Mixed inferred formats fail before any document contents are read. Empty input returns JSON layers unless overridden.