pub enum AccumulateError {
CurrentDirectory(Error),
Inspect {
path: PathBuf,
source: Error,
},
List {
path: PathBuf,
source: Error,
},
Directory {
path: PathBuf,
},
NonRegular {
path: PathBuf,
},
}Expand description
A filesystem failure during discovery. Paths are structured diagnostic data.
Variants
CurrentDirectory(Error)
The working directory could not be obtained for a relative base.
Inspect
Metadata could not be read (symlinks are followed).
List
A directory or one of its entries could not be read.
Directory
The named target is a directory.
NonRegular
The named target is neither a directory nor a regular file.