Native value adapters for the shared merge and interpolation algorithms.
Traits
- Config
Object - An ordered object whose children have the same native value type.
- Config
Value - Structural operations on a native configuration value.
Native value adapters for the shared merge and interpolation algorithms.