Module value

Module value 

Native value adapters for the shared merge and interpolation algorithms.

Traits

ConfigObject
An ordered object whose children have the same native value type.
ConfigValue
Structural operations on a native configuration value.